##  Managing Calculations
You can manage calculations in the Calculations section of the administration area. Here, you can:
  * Activate calculations: To activate a calculation saved as a draft earlier, on the calculation page, click Save and Activate.
  * Deactivate calculations: To deactivate an active calculation, in the upper-right corner of the calculation page, click the three-dot icon > Disable.
  * Delete calculations: Proceed with caution as this action cannot be undone. You may want to deactivate calculations instead. To delete a calculation, in the upper-right corner of the calculation page, click the three-dot icon > Delete.
